from abaqus.DisplayGroup.Leaf import Leaf  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromConstraintNames import LeafFromConstraintNames  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromDisplayGroup import LeafFromDisplayGroup  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromElementLabels import LeafFromElementLabels  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromElementSets import LeafFromElementSets  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromElementVarRange import LeafFromElementVarRange  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromModelElemLabels import LeafFromModelElemLabels  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromModelNodeLabels import LeafFromModelNodeLabels  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromNodeLabels import LeafFromNodeLabels  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromNodeSets import LeafFromNodeSets  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromNodeVarRange import LeafFromNodeVarRange  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromOdbEdgePick import LeafFromOdbEdgePick  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromOdbElementLayups import LeafFromOdbElementLayups  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromOdbElementMaterials import LeafFromOdbElementMaterials  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromOdbElementPick import LeafFromOdbElementPick  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromOdbElementPlies import LeafFromOdbElementPlies  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromOdbElementSections import LeafFromOdbElementSections  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromOdbElementTypes import LeafFromOdbElementTypes  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromOdbNodePick import LeafFromOdbNodePick  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromPartInstance import LeafFromPartInstance  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromSurfaceSets import LeafFromSurfaceSets  # noqa # pylint: disable=unused-import
from abaqus.DisplayGroup.LeafFromSurfaceVarRange import LeafFromSurfaceVarRange  # noqa # pylint: disable=unused-import



from typing import Optional

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from typing_extensions import Literal

from ...UtilityAndView.abaqusConstants import Boolean, OFF
from ...UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class TensileFailure:
    """The TensileFailure object specifies the material tensile failure.

    .. note::
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].Plastic.tensileFailure
            mdb.models[name].materials[name].eos.tensileFailure
            import odbMaterial
            session.odbs[name].materials[name].Plastic.tensileFailure
            session.odbs[name].materials[name].eos.tensileFailure

        The table data for this object are:

        - The Hydrostatic cutoff stress (positive in tension).
        - Temperature, if the data depend on temperature.
        - Value of the first field variable if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - TENSILE FAILURE

    .. versionadded:: 2020
        The `TensileFailure` class was added.
    """

    @abaqus_method_doc
    def tensileFailure(
        self,
        table: tuple,
        dependencies: int = 0,
        temperatureDependency: Boolean = OFF,
        elementDeletion: Boolean = True,
        pressure: Optional[Literal[C.BRITTLE, C.DUCTILE]] = None,
        shear: Optional[Literal[C.BRITTLE, C.DUCTILE]] = None,
    ):
        """This method creates a tensileFailure object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].Plastic.TensileFailure
                mdb.models[name].materials[name].eos.TensileFailure
                session.odbs[name].materials[name].Plastic.TensileFailure
                session.odbs[name].materials[name].eos.TensileFailure

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        temperatureDependency
            A boolean specifying whether the data depends on temperature. The default value is OFF.
        elementDeletion
            A boolean specifying whether element deletion is allowed. The default value is True.
        pressure
            A SymbolicConstant specifying the pressure stress. The Possible values are BRITTLE and
            DUCTILE.
        shear
            A SymbolicConstant specifying the deviatoric stress. Possible values are BRITTLE and
            DUCTILE.

        Returns
        -------
        TensileFailure
            An TensileFailure object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the TensileFailure object.

        Raises
        ------
        RangeError
        """
        ...



from typing import Optional

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from typing_extensions import Literal

from .GeometricRestriction import GeometricRestriction
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import Boolean, FREE_FORM, ON, SymbolicConstant
from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class SlideRegionControl(GeometricRestriction):
    """The SlideRegionControl object defines a slide region control geometric restriction.
    The SlideRegionControl object is derived from the GeometricRestriction object.

    .. note::
        This object can be accessed by::

            import optimization
            mdb.models[name].optimizationTasks[name].geometricRestrictions[name]
    """

    #: A String specifying the geometric restriction repository key.
    name: str

    #: A VertexArray object of length 2 specifying the axis of revolution. Instead of through a
    #: ConstrainedSketchVertex, each point may be specified through a tuple of coordinates. This is used when
    #: **approach** is TURN.
    clientDirection: tuple

    #: A Region object specifying the region to which the geometric restriction is applied.
    #: When used with a TopologyTask, there is no default value. When used with a ShapeTask,
    #: the default value is MODEL.
    region: Region

    #: A SymbolicConstant specifying the restriction approach. The SymbolicConstant FREE_FORM
    #: indicates a free-form slide region, and the SymbolicConstant TURN indicates that the
    #: restriction should conserve a turnable surface. Possible values are FREE_FORM and TURN.
    #: The default value is FREE_FORM.
    approach: SymbolicConstant = FREE_FORM

    #: None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
    #: global coordinate system is used. When this member is queried, it returns an Int. This
    #: is used when **approach** is TURN. The default value is None.
    csys: Optional[int] = None

    #: None or a Region object specifying the free-form region. This is used when **approach** is
    #: FREE_FORM. The default value is None.
    freeFormRegion: Optional[str] = None

    #: A Boolean specifying whether to ignore the geometric restriction in the first design
    #: cycle. The default value is ON.
    presumeFeasibleRegionAtStart: Boolean = ON

    #: None or a Region object specifying the region to revolve into a slide region. This is
    #: used when **approach** is TURN. The default value is None.
    revolvedRegion: Optional[str] = None

    #: A Float specifying the geometric tolerance in the 1-direction. This is used when
    #: **approach** is TURN. The default value is 0.01.
    tolerance1: float = 0

    #: A Float specifying the geometric tolerance in the 2-direction. This is used when
    #: **approach** is TURN. The default value is 0.01.
    tolerance2: float = 0

    #: A Float specifying the geometric tolerance in the 3-direction. This is used when
    #: **approach** is TURN. The default value is 0.01.
    tolerance3: float = 0

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        clientDirection: tuple,
        region: Region,
        approach: Literal[C.FREE_FORM, C.TURN] = FREE_FORM,
        csys: Optional[int] = None,
        freeFormRegion: Optional[str] = None,
        presumeFeasibleRegionAtStart: Boolean = ON,
        revolvedRegion: Optional[str] = None,
        tolerance1: float = 0,
        tolerance2: float = 0,
        tolerance3: float = 0,
    ):
        """This method creates a SlideRegionControl object.

        .. note::
            This function can be accessed by::

                mdb.models[name].optimizationTasks[name].SlideRegionControl

        Parameters
        ----------
        name
            A String specifying the geometric restriction repository key.
        clientDirection
            A VertexArray object of length 2 specifying the axis of revolution. Instead of through a
            ConstrainedSketchVertex, each point may be specified through a tuple of coordinates. This is used when
            **approach** is TURN.
        region
            A Region object specifying the region to which the geometric restriction is applied.
            When used with a TopologyTask, there is no default value. When used with a ShapeTask,
            the default value is MODEL.
        approach
            A SymbolicConstant specifying the restriction approach. The SymbolicConstant FREE_FORM
            indicates a free-form slide region, and the SymbolicConstant TURN indicates that the
            restriction should conserve a turnable surface. Possible values are FREE_FORM and TURN.
            The default value is FREE_FORM.
        csys
            None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
            global coordinate system is used. When this member is queried, it returns an Int. This
            is used when **approach** is TURN. The default value is None.
        freeFormRegion
            None or a Region object specifying the free-form region. This is used when **approach** is
            FREE_FORM. The default value is None.
        presumeFeasibleRegionAtStart
            A Boolean specifying whether to ignore the geometric restriction in the first design
            cycle. The default value is ON.
        revolvedRegion
            None or a Region object specifying the region to revolve into a slide region. This is
            used when **approach** is TURN. The default value is None.
        tolerance1
            A Float specifying the geometric tolerance in the 1-direction. This is used when
            **approach** is TURN. The default value is 0.01.
        tolerance2
            A Float specifying the geometric tolerance in the 2-direction. This is used when
            **approach** is TURN. The default value is 0.01.
        tolerance3
            A Float specifying the geometric tolerance in the 3-direction. This is used when
            **approach** is TURN. The default value is 0.01.

        Returns
        -------
        SlideRegionControl
            A SlideRegionControl object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        approach: Literal[C.FREE_FORM, C.TURN] = FREE_FORM,
        csys: Optional[int] = None,
        freeFormRegion: Optional[str] = None,
        presumeFeasibleRegionAtStart: Boolean = ON,
        revolvedRegion: Optional[str] = None,
        tolerance1: float = 0,
        tolerance2: float = 0,
        tolerance3: float = 0,
    ):
        """This method modifies the SlideRegionControl object.

        Parameters
        ----------
        approach
            A SymbolicConstant specifying the restriction approach. The SymbolicConstant FREE_FORM
            indicates a free-form slide region, and the SymbolicConstant TURN indicates that the
            restriction should conserve a turnable surface. Possible values are FREE_FORM and TURN.
            The default value is FREE_FORM.
        csys
            None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
            global coordinate system is used. When this member is queried, it returns an Int. This
            is used when **approach** is TURN. The default value is None.
        freeFormRegion
            None or a Region object specifying the free-form region. This is used when **approach** is
            FREE_FORM. The default value is None.
        presumeFeasibleRegionAtStart
            A Boolean specifying whether to ignore the geometric restriction in the first design
            cycle. The default value is ON.
        revolvedRegion
            None or a Region object specifying the region to revolve into a slide region. This is
            used when **approach** is TURN. The default value is None.
        tolerance1
            A Float specifying the geometric tolerance in the 1-direction. This is used when
            **approach** is TURN. The default value is 0.01.
        tolerance2
            A Float specifying the geometric tolerance in the 2-direction. This is used when
            **approach** is TURN. The default value is 0.01.
        tolerance3
            A Float specifying the geometric tolerance in the 3-direction. This is used when
            **approach** is TURN. The default value is 0.01.
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from typing_extensions import Literal

from ..UtilityAndView.abaqusConstants import LOGARITHMIC, SymbolicConstant
from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class Regularization:
    """The Regularization object defines the tolerance to be used for regularizing material
    data.

    .. note::
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].regularization
            import odbMaterial
            session.odbs[name].materials[name].regularization

        The corresponding analysis keywords are:

        - DASHPOT
    """

    #: A Float specifying the tolerance to be used for regularizing material data. The default
    #: value is 0.03.
    rtol: float = 0

    #: A SymbolicConstant specifying the form of regularization of strain-rate-dependent
    #: material data. Possible values are LOGARITHMIC and LINEAR. The default value is
    #: LOGARITHMIC.
    strainRateRegularization: SymbolicConstant = LOGARITHMIC

    @abaqus_method_doc
    def __init__(self, rtol: float = 0, strainRateRegularization: Literal[C.LINEAR, C.LOGARITHMIC] = LOGARITHMIC):
        """This method creates a Regularization object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].Regularization
                session.odbs[name].materials[name].Regularization

        Parameters
        ----------
        rtol
            A Float specifying the tolerance to be used for regularizing material data. The default
            value is 0.03.
        strainRateRegularization
            A SymbolicConstant specifying the form of regularization of strain-rate-dependent
            material data. Possible values are LOGARITHMIC and LINEAR. The default value is
            LOGARITHMIC.

        Returns
        -------
        Regularization
            A Regularization object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the Regularization object.

        Raises
        ------
        RangeError
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from typing_extensions import Literal

from .Trs import Trs
from .....UtilityAndView.abaqusConstants import Boolean, NEWTONIAN, OFF
from .....UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class Viscosity:
    """The Viscosity object specifies mechanical viscosity.

    .. note::
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].viscosity
            import odbMaterial
            session.odbs[name].materials[name].viscosity

        The table data for this object are:

        - If **type** = NEWTONIAN, the table data specify the following:

        - Viscosity, :math:`k`.
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - VISCOSITY
    """

    #: A Trs object.
    trs: Trs = Trs()

    @abaqus_method_doc
    def __init__(
        self,
        table: tuple,
        type: Literal[C.NEWTONIAN] = NEWTONIAN,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a Viscosity object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].Viscosity
                session.odbs[name].materials[name].Viscosity

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        type
            A SymbolicConstant specifying the type of viscosity. The default value is NEWTONIAN.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        Viscosity
            A Viscosity object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the Viscosity object.

        Raises
        ------
        RangeError
        """
        ...



from __future__ import annotations

from typing import Union, List, Dict, Sequence, overload, Tuple

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .IgnoredVertex import IgnoredVertex
from ..UtilityAndView.abaqusConstants import Boolean


@abaqus_class_doc
class IgnoredVertexArray(List[IgnoredVertex]):
    """The IgnoredVertexArray is a sequence of IgnoredVertex objects. If the part is modified,
    then IgnoredVertexArray must be updated for that part.

    .. note::
        This object can be accessed by::

            import part
            mdb.models[name].parts[name].ignoredVertices
            import assembly
            mdb.models[name].rootAssembly.allInstances[name].ignoredVertices
            mdb.models[name].rootAssembly.instances[name].ignoredVertices
    """

    @overload
    @abaqus_method_doc
    def findAt(self, coordinates: Tuple[float, float, float], printWarning: Boolean = True) -> IgnoredVertex:
        ...

    @overload
    @abaqus_method_doc
    def findAt(
        self,
        coordinates: Tuple[
            Tuple[float, float, float],
        ],
        printWarning: Boolean = True,
    ) -> List[IgnoredVertex]:
        ...

    @overload
    @abaqus_method_doc
    def findAt(
        self,
        *coordinates: Tuple[
            Tuple[float, float, float],
        ],
        printWarning: Boolean = True,
    ) -> List[IgnoredVertex]:
        ...

    @abaqus_method_doc
    def findAt(self, *args, **kwargs) -> Union[IgnoredVertex, List[IgnoredVertex]]:
        """This method returns the object or objects in the IgnoredVertexArray located at the given
        coordinates.
        findAt initially uses the ACIS tolerance of 1E-6. As a result, findAt returns any
        IgnoredVertex object that is at the arbitrary point specified or at a distance of less
        than 1E-6 from the arbitrary point. If nothing is found, findAt uses the tolerance for
        imprecise geometry (applicable only for imprecise geometric entities).
        findAt will always try to find objects among all the ignored vertices in the part or
        assembly instance and will not restrict itself to a subset even if the
        IgnoredVertexArray represents such subset.

        Parameters
        ----------
        coordinates
            A sequence of Floats specifying the **X**-, **Y**-, and **Z**-coordinates of the object to
            find.findAt returns either a IgnoredVertex object or a sequence of IgnoredVertex objects
            based on the type of input.

            * If **coordinates** is a sequence of Floats, findAt returns the IgnoredVertex object at that point.

            * If you omit the **coordinates** keyword argument, findAt accepts as arguments
              a sequence of sequence of floats in the following format::

                verts = v.findAt(((20.19686, -169.513997, 27.798593), ),
                                ((19.657627, -167.295749, 27.056402), ),
                                ((18.274129, -157.144741, 25.15218), ))
        printWarning
            A Boolean specifying whether a message is to be printed to the CLI if no entity is found
            at the specified location. The default value is True.

        Returns
        -------
        IgnoredVertex
            An IgnoredVertex object or a sequence of IgnoredVertex objects.

        """
        first_arg = kwargs.get("coordinates", args[0] if args else ((),))
        return IgnoredVertex() if isinstance(first_arg[0], float) else [IgnoredVertex()]

    @overload
    @abaqus_method_doc
    def getSequenceFromMask(self, mask: str) -> IgnoredVertex:
        ...

    @overload
    @abaqus_method_doc
    def getSequenceFromMask(self, mask: Sequence[str]) -> List[IgnoredVertex]:
        ...

    @abaqus_method_doc
    def getSequenceFromMask(self, mask: Union[str, Sequence[str]]) -> Union[IgnoredVertex, List[IgnoredVertex]]:
        """This method returns the object or objects in the IgnoredVertexArray identified using the
        specified **mask**. This command is generated when the JournalOptions are set to
        COMPRESSEDINDEX. When large number of objects are involved, this method is highly
        efficient.

        Parameters
        ----------
        mask
            A String specifying the object or objects.

        Returns
        -------
        IgnoredVertex
            An IgnoredVertex object or a sequence of IgnoredVertex objects.

        """
        ...

    @abaqus_method_doc
    def getMask(self):
        """This method returns a string specifying the object or objects.

        Returns
        -------
        str
            A String specifying the object or objects.

        """
        ...

    @abaqus_method_doc
    def getClosest(self, coordinates: tuple, searchTolerance: str = "") -> Dict:
        """This method returns a object or objects in the IgnoredVertexArray closest to the given
        set of points, where the given points need not lie on the vertices in the
        IgnoredVertexArray.

        Parameters
        ----------
        coordinates
            A sequence of a sequence of floats, where each sequence of floats describes the **X**-,
            **Y**-, and **Z**-coordinates of a point::

                >>> r=e.getClosest(coordinates=((20.0, 20.0, 10.0),(-1.0, -15.0, 15), ))
                >>> r.keys()
                [0, 1]
                >>> r[0]
                (mdb.models['Model-1'].parts['Part-1'].ignoredVertices[3], (15.7090625762939, 20.0, 10.0))
        searchTolerance
            A double specifying the distance within which the closest object must lie. The default
            value is half of the parent part/instance size.

        Returns
        -------
        dict
            This method returns a dictionary object. The key to the dictionary object is the
            position of the input point in the tuple specified in the **coordinates** starting at
            index 0. If a closest IgnoredVertex could be found then the value is a sequence
            consisting of two objects. The first object in the sequence is a IgnoredVertex that is
            close to the input point referred to by the key. The second object in the sequence, is a
            sequence of floats which specify the **X**-, **Y**-, and **Z**- location of the IgnoredVertex.
            See program listing above.

        Raises
        ------
        Error: The mask results in an empty sequence
            An exception occurs if the resulting sequence is empty.
        """
        ...



from typing import Optional

from abqpy.decorators import abaqus_class_doc

from .OdbDatumCsys import OdbDatumCsys
from .OdbSet import OdbSet
from ..UtilityAndView.abaqusConstants import SymbolicConstant


@abaqus_class_doc
class RebarOrientation:
    """The RebarOrientation object represents the orientation of the rebar reference.

    .. note::
        This object can be accessed by::

            import odbAccess
            session.odbs[name].parts[name].rebarOrientations[i]
            session.odbs[name].rootAssembly.instances[name].rebarOrientations[i]
            session.odbs[name].steps[name].frames[i].fieldOutputs[name].values[i].instance.rebarOrientations[i]
    """

    #: A SymbolicConstant specifying the axis of a cylindrical or spherical datum coordinate
    #: system about which an additional rotation is applied. Possible values are AXIS_1,
    #: AXIS_2, and AXIS_3.
    axis: Optional[SymbolicConstant] = None

    #: A Float specifying the angle of the additional rotation.
    angle: Optional[float] = None

    #: An OdbSet object specifying a region for which the rebar orientation is defined.
    region: OdbSet = OdbSet("set", ())

    #: An OdbDatumCsys object specifying a datum coordinates system.
    csys: OdbDatumCsys = OdbDatumCsys()



from typing import Optional

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .Interaction import Interaction
from ..Region.RegionArray import RegionArray
from ..UtilityAndView.abaqusConstants import UNSET


@abaqus_class_doc
class PressurePenetration(Interaction):
    """The PressurePenetration object defines pressure penetration loading simulated with
    surface-to-surface contact.
    The PressurePenetration object is derived from the Interaction object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].interactions[name]

        The corresponding analysis keywords are:

        - PRESSURE PENETRATION
    """

    #: A String specifying the repository key.
    name: str = ""

    #: A String specifying the name of the step in which the PressurePenetration object is
    #: created.
    createStepName: str = ""

    #: A String specifying the name of the Surface-to-surface contact (Standard) interaction.
    contactInteraction: str = ""

    #: A RegionArray object specifying the points on the master surface that are exposed to the
    #: fluid.
    masterPoints: RegionArray = []

    #: A RegionArray object specifying the points on the slave surface that are exposed to
    #: the fluid.
    slavePoints: RegionArray = []

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        contactInteraction: str,
        masterPoints: RegionArray,
        slavePoints: RegionArray,
        penetrationPressure: float,
        criticalPressure: float,
        amplitude: str = UNSET,
        penetrationTime: float = 0,
    ):
        """This method creates a PressurePenetration object.

        .. note::
            This function can be accessed by::

                mdb.models[name].PressurePenetration

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the PressurePenetration object is
            created.
        contactInteraction
            A String specifying the name of the Surface-to-surface contact (Standard) interaction.
        masterPoints
            A RegionArray object specifying the points on the master surface that are exposed to the
            fluid.
        slavePoints
            A RegionArray object specifying the points on the slave surface that are exposed to
            the fluid.
        penetrationPressure
            A tuple of Floats specifying the fluid pressure magnitude. For steady state dynamic
            analyses, a tuple of Complexes specifying the fluid pressure magnitude.
        criticalPressure
            A tuple of Floats specifying the critical contact pressure below which fluid penetration
            starts to occur.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        penetrationTime
            A Float specifying the fraction of the current step time over which the fluid pressure
            on newly penetrated contact surface segments is ramped up to the current magnitude. The
            default value is 0.001.

        Returns
        -------
        PressurePenetration
            A PressurePenetration object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, amplitude: str = UNSET, penetrationTime: float = 0):
        """This method modifies the data for an existing PressurePenetration object in the step
        where it is created.

        Parameters
        ----------
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        penetrationTime
            A Float specifying the fraction of the current step time over which the fluid pressure
            on newly penetrated contact surface segments is ramped up to the current magnitude. The
            default value is 0.001.
        """
        ...

    @abaqus_method_doc
    def setValuesInStep(
        self,
        stepName: str,
        penetrationPressure: Optional[float] = None,
        criticalPressure: Optional[float] = None,
        amplitude: str = "",
        penetrationTime: float = 0,
    ):
        """This method modifies the propagating data for an existing PressurePenetration object in
        the specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the interaction is modified.
        penetrationPressure
            A tuple of Floats specifying the fluid pressure magnitude. For steady state dynamic
            analyses, a tuple of Complexes specifying the fluid pressure magnitude.
        criticalPressure
            A tuple of Floats specifying the critical contact pressure below which fluid penetration
            starts to occur.
        amplitude
            A String or a SymbolicConstant specifying the name of the amplitude reference. Possible
            values for the SymbolicConstant are UNCHANGED and FREED. UNCHANGED should be used if the
            amplitude is propagated from the previous analysis step. FREED should be used if the
            load is changed to have no amplitude reference. You should provide the **amplitude**
            argument only if it is valid for the specified step.
        penetrationTime
            A Float specifying the fraction of the current step time over which the fluid pressure
            on newly penetrated contact surface segments is ramped up to the current magnitude. The
            default value is 0.001.
        """
        ...



from typing import Optional

from abqpy.decorators import abaqus_class_doc

from .LoadState import LoadState
from ..UtilityAndView.abaqusConstants import SymbolicConstant


@abaqus_class_doc
class ConnectorMomentState(LoadState):
    """The ConnectorMomentState object stores the propagating data for a connector moment in a
    step. One instance of this object is created internally by the ConnectorMoment object
    for each step. The instance is also deleted internally by the ConnectorMoment object.
    The ConnectorMomentState object has no constructor or methods.
    The ConnectorMomentState object is derived from the LoadState object.

    .. note::
        This object can be accessed by::

            import load
            mdb.models[name].steps[name].loadStates[name]

        The corresponding analysis keywords are:

        - CONNECTOR LOAD
    """

    #: A Float or a Complex specifying the connector moment component in the connector's local
    #: 4-direction. Although **m1**, **m2**, and **m3** are optional arguments, at least one of them
    #: must be nonzero.
    m1: Optional[float] = None

    #: A Float or a Complex specifying the connector moment component in the connector's local
    #: 5direction.
    m2: Optional[float] = None

    #: A Float or a Complex specifying the connector moment component in the connector's local
    #: 6-direction.
    m3: Optional[float] = None

    #: A SymbolicConstant specifying the propagation state of the load component in the
    #: connector's local 4-direction. Possible values are UNSET, SET, UNCHANGED, and FREED.
    m1State: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the load component in the
    #: connector's local 5-direction. Possible values are UNSET, SET, UNCHANGED, and FREED.
    m2State: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the load component in the
    #: connector's local 6-direction. Possible values are UNSET, SET, UNCHANGED, and FREED.
    m3State: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the LoadState object. Possible
    #: values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: Optional[SymbolicConstant] = None

    #: A String specifying the name of the amplitude reference. The String is empty if the load
    #: has no amplitude reference.
    amplitude: str = ""



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from typing_extensions import Literal

from .GeometricRestriction import GeometricRestriction
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import MINIMUM, OFF, SymbolicConstant
from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class ShapeMemberSize(GeometricRestriction):
    """The ShapeMemberSize object defines a shape member size geometric restriction.
    The ShapeMemberSize object is derived from the GeometricRestriction object.

    .. note::
        This object can be accessed by::

            import optimization
            mdb.models[name].optimizationTasks[name].geometricRestrictions[name]
    """

    #: A String specifying the geometric restriction repository key.
    name: str

    #: A Region object specifying the region to which the geometric restriction is applied.
    #: When used with a TopologyTask, there is no default value. When used with a ShapeTask,
    #: the default value is MODEL.
    region: Region

    #: A Float specifying the maximum thickness. The default value is 0.0.
    maxThickness: float = 0

    #: A Float specifying the minimum thickness. The default value is 0.0.
    minThickness: float = 0

    #: A SymbolicConstant specifying whether to restrict the minimum or maximum thickness.
    #: Possible values are MAXIMUM and MINIMUM. The default value is MINIMUM.
    sizeRestriction: SymbolicConstant = MINIMUM

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        region: Region,
        maxThickness: float = 0,
        minThickness: float = 0,
        sizeRestriction: Literal[C.MINIMUM, C.MAXIMUM] = MINIMUM,
    ):
        """This method creates a ShapeMemberSize object.

        .. note::
            This function can be accessed by::

                mdb.models[name].optimizationTasks[name].ShapeMemberSize

        Parameters
        ----------
        name
            A String specifying the geometric restriction repository key.
        region
            A Region object specifying the region to which the geometric restriction is applied.
            When used with a TopologyTask, there is no default value. When used with a ShapeTask,
            the default value is MODEL.
        maxThickness
            A Float specifying the maximum thickness. The default value is 0.0.
        minThickness
            A Float specifying the minimum thickness. The default value is 0.0.
        sizeRestriction
            A SymbolicConstant specifying whether to restrict the minimum or maximum thickness.
            Possible values are MAXIMUM and MINIMUM. The default value is MINIMUM.

        Returns
        -------
        ShapeMemberSize
            A ShapeMemberSize object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        maxThickness: float = 0,
        minThickness: float = 0,
        sizeRestriction: Literal[C.MINIMUM, C.MAXIMUM] = MINIMUM,
        assignNodeGroupRegion: str = OFF,
        nodeGroupRegion: str = "",
    ):
        """This method modifies the ShapeMemberSize object.

        Parameters
        ----------
        maxThickness
            A Float specifying the maximum thickness. The default value is 0.0.
        minThickness
            A Float specifying the minimum thickness. The default value is 0.0.
        sizeRestriction
            A SymbolicConstant specifying whether to restrict the minimum or maximum thickness.
            Possible values are MAXIMUM and MINIMUM. The default value is MINIMUM.
        assignNodeGroupRegion
            A bool specifying whether to use the node group region. The default value is OFF.
        nodeGroupRegion
            A Node Region object specifying the check node group.
        """
        ...



from typing import Optional

from abqpy.decorators import abaqus_class_doc

from .BoundaryConditionState import BoundaryConditionState
from ..UtilityAndView.abaqusConstants import SymbolicConstant


@abaqus_class_doc
class MaterialFlowBCState(BoundaryConditionState):
    """The MaterialFlowBCState object stores the propagating data for a connector material flow
    boundary condition in a step. One instance of this object is created internally by the
    MaterialFlowBC object for each step. The instance is also deleted internally by the
    MaterialFlowBC object.
    The MaterialFlowBCState object has no constructor or methods.
    The MaterialFlowBCState object is derived from the BoundaryConditionState object.

    .. note::
        This object can be accessed by::

            import load
            mdb.models[name].steps[name].boundaryConditionStates[name]

        The corresponding analysis keywords are:

        - BOUNDARY
    """

    #: A Float specifying the material flow magnitude.
    magnitude: Optional[float] = None

    #: A SymbolicConstant specifying the propagation state of the material flow magnitude.
    #: Possible values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    magnitudeState: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the amplitude reference. Possible
    #: values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    amplitudeState: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the BoundaryConditionState object. Possible values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - PROPAGATED_FROM_BASE_STATE
    #: - MODIFIED_FROM_BASE_STATE
    #: - DEACTIVATED_FROM_BASE_STATE
    #: - BUILT_INTO_MODES
    status: Optional[SymbolicConstant] = None

    #: A String specifying the name of the amplitude reference. The String is empty if the
    #: boundary condition has no amplitude reference.
    amplitude: str = ""



from typing import Optional

from abqpy.decorators import abaqus_class_doc

from .InteractionState import InteractionState
from ..UtilityAndView.abaqusConstants import SymbolicConstant


@abaqus_class_doc
class SelfContactExpState(InteractionState):
    """The SelfContactExpState object stores the propagating data for a SelfContactExp object.
    One instance of this object is created internally by the SelfContactExp object for each
    step. The instance is also deleted internally by the SelfContactExp object.
    The SelfContactExpState object has no constructor or methods.
    The SelfContactExpState object is derived from the InteractionState object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].steps[name].interactionStates[name]

        The corresponding analysis keywords are:

        - CONTACT CONTROLS
        - CONTACT PAIR
        - MODEL CHANGE
    """

    #: A SymbolicConstant specifying the propagation state of the **interactionProperty** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    interactionPropertyState: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the **contactControls** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    contactControlsState: Optional[SymbolicConstant] = None

    #: A String specifying the name of the ContactProperty object associated with this
    #: interaction.
    interactionProperty: str = ""

    #: A String specifying the name of the ContactControl object associated with this
    #: interaction.
    contactControls: str = ""

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: Optional[SymbolicConstant] = None



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .Constraint import Constraint
from ..UtilityAndView.abaqusConstants import Boolean, OFF


@abaqus_class_doc
class Equation(Constraint):
    """The Equation object defines a linear multi-point constraint between a set of degrees of
    freedom.
    The Equation object is derived from the ConstrainedSketchConstraint object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].constraints[name]

        The corresponding analysis keywords are:

        - EQUATION
    """

    #: A Boolean specifying whether the constraint is suppressed or not. The default value is
    #: OFF.
    suppressed: Boolean = OFF

    #: A String specifying the constraint repository key.
    name: str

    #: A sequence of (Float, String, Int, Int) sequences specifying a coefficient, Set name,
    #: degree of freedom, and coordinate system ID. The coordinate system ID is optional.
    terms: tuple

    @abaqus_method_doc
    def __init__(self, name: str, terms: tuple):
        """This method creates an Equation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].Equation

        Parameters
        ----------
        name
            A String specifying the constraint repository key.
        terms
            A sequence of (Float, String, Int, Int) sequences specifying a coefficient, Set name,
            degree of freedom, and coordinate system ID. The coordinate system ID is optional.

        Returns
        -------
        Equation
            An Equation object.

        Raises
        ------
        If **terms** does not contain more than one entry, Equation must have two or more terms.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the Equation object.

        Raises
        ------
        If **terms** does not contain more than one entry, Equation must have two or more terms.
        """
        ...



from typing import Optional

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .Load import Load
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import Boolean, ON


@abaqus_class_doc
class SubmodelSB(Load):
    """The SubmodelSB object stores the data for a submodel surface based load.
    The SubmodelSB object is derived from the Load object.

    .. note::
        This object can be accessed by::

            import load
            mdb.models[name].loads[name]
    """

    #: A String specifying the load repository key.
    name: str = ""

    #: None or a Float specifying the absolute value by which a driven node of the submodel can
    #: lie outside the region of the elements of the global model. The default value is None.
    absoluteExteriorTolerance: Optional[float] = None

    #: None or a Float specifying the fraction of the average element size in the global model
    #: by which a driven node of the submodel can lie outside the region of the elements of the
    #: global model. The default value is 0.05.
    exteriorTolerance: float = 0

    #: A String specifying the element set in the global model that will be searched for
    #: elements whose responses will be used to drive the submodel. An empty string indicates
    #: that the entire global model will be searched. The default value is an empty string.
    globalDrivingRegion: str = ""

    #: A Region object specifying the region to which the load is applied.
    region: Region = Region()

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        region: Region,
        globalStep: str,
        globalDrivingRegion: str = "",
        absoluteExteriorTolerance: Optional[float] = None,
        exteriorTolerance: float = 0,
        globalIncrement: int = 0,
    ):
        """This method creates a SubmodelSB object.

        .. note::
            This function can be accessed by::

                mdb.models[name].SubmodelSB

        Parameters
        ----------
        name
            A String specifying the load repository key.
        createStepName
            A String specifying the name of the step in which the load is created.
        region
            A Region object specifying the region to which the load is applied.
        globalStep
            A String specifying the step in the global model from which Abaqus reads the values of
            the variables that will drive the submodel analysis. The String indicates the position
            of the step in the sequence of analysis steps. For example, **globalStep** = '1' indicates
            the first step.
        globalDrivingRegion
            A String specifying the element set in the global model that will be searched for
            elements whose responses will be used to drive the submodel. An empty string indicates
            that the entire global model will be searched. The default value is an empty string.
        absoluteExteriorTolerance
            None or a Float specifying the absolute value by which a driven node of the submodel can
            lie outside the region of the elements of the global model. The default value is None.
        exteriorTolerance
            None or a Float specifying the fraction of the average element size in the global model
            by which a driven node of the submodel can lie outside the region of the elements of the
            global model. The default value is 0.05.
        globalIncrement
            An Int specifying the increment number in the global model step from which the solution
            will be used to specify the values of the driven variables. If **globalIncrement** = 0, the
            solution from the last increment will be used. The **globalIncrement** argument is
            applicable only for linear perturbation steps. The default value is 0.

        Returns
        -------
        SubmodelSB
            A SubmodelSB object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        globalDrivingRegion: str = "",
        absoluteExteriorTolerance: Optional[float] = None,
        exteriorTolerance: float = 0,
        globalIncrement: int = 0,
    ):
        """This method modifies the data for an existing SubmodelSB object in the step where it is
        created.

        Parameters
        ----------
        globalDrivingRegion
            A String specifying the element set in the global model that will be searched for
            elements whose responses will be used to drive the submodel. An empty string indicates
            that the entire global model will be searched. The default value is an empty string.
        absoluteExteriorTolerance
            None or a Float specifying the absolute value by which a driven node of the submodel can
            lie outside the region of the elements of the global model. The default value is None.
        exteriorTolerance
            None or a Float specifying the fraction of the average element size in the global model
            by which a driven node of the submodel can lie outside the region of the elements of the
            global model. The default value is 0.05.
        globalIncrement
            An Int specifying the increment number in the global model step from which the solution
            will be used to specify the values of the driven variables. If **globalIncrement** = 0, the
            solution from the last increment will be used. The **globalIncrement** argument is
            applicable only for linear perturbation steps. The default value is 0.
        """
        ...

    @abaqus_method_doc
    def setValuesInStep(
        self,
        stepName: str,
        fixed: Boolean = ON,
        globalStep: str = "",
        globalIncrement: int = 0,
    ):
        """This method modifies the propagating data for an existing SubmodelSB object in the
        specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the load is modified.
        fixed
            A Boolean specifying whether the load should remain fixed at the current values at the
            start of the step. The default value is ON.
        globalStep
            A String specifying the step in the global model from which Abaqus reads the values of
            the variables that will drive the submodel analysis. The String indicates the position
            of the step in the sequence of analysis steps. For example, **globalStep** = '1' indicates
            the first step. The **globalStep** argument is applicable only if **fixed** = OFF.
        globalIncrement
            An Int specifying the increment number in the global model step at which the solution
            will be used to specify the values of the driven variables. If **globalIncrement** = 0, the
            solution from the last increment will be used. The **globalIncrement** argument is
            applicable only for linear perturbation steps and if **fixed** = OFF. The default value is
            0.
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .Profile import Profile


@abaqus_class_doc
class IProfile(Profile):
    """The IProfile object defines the properties of an I profile.
    The IProfile object is derived from the Profile object.

    .. note::
        This object can be accessed by::

            import section
            mdb.models[name].profiles[name]
            import odbSection
            session.odbs[name].profiles[name]

        The corresponding analysis keywords are:

        - BEAM SECTION
    """

    #: A String specifying the repository key.
    name: str

    #: A Float specifying the **l** dimension (offset of 1-axis from the bottom flange surface)
    #: of the I profile. For more information, see [Beam cross-section
    #: library](https://help.3ds.com/2021/English/DSSIMULIA_Established/SIMACAEELMRefMap/simaelm-c-beamcrosssectlib.htm?ContextScope=all).
    l: float

    #: A Float specifying the **h** dimension (height) of the I profile.
    h: float

    #: A Float specifying the **b1** dimension (bottom flange width) of the I profile.
    b1: float

    #: A Float specifying the **b2** dimension (top flange width) of the I profile.
    b2: float

    #: A Float specifying the **t1** dimension (bottom flange thickness) of the I profile.
    t1: float

    #: A Float specifying the **t2** dimension (top flange thickness) of the I profile.
    t2: float

    #: A Float specifying the **t3** dimension (web thickness) of the I profile.
    t3: float

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        l: float,
        h: float,
        b1: float,
        b2: float,
        t1: float,
        t2: float,
        t3: float,
    ):
        """This method creates an IProfile object.

        .. note::
            This function can be accessed by::

                mdb.models[name].IProfile
                session.odbs[name].IProfile

        Parameters
        ----------
        name
            A String specifying the repository key.
        l
            A Float specifying the **l** dimension (offset of 1-axis from the bottom flange surface)
            of the I profile. For more information, see [Beam cross-section
            library](https://help.3ds.com/2021/English/DSSIMULIA_Established/SIMACAEELMRefMap/simaelm-c-beamcrosssectlib.htm?ContextScope=all).
        h
            A Float specifying the **h** dimension (height) of the I profile.
        b1
            A Float specifying the **b1** dimension (bottom flange width) of the I profile.
        b2
            A Float specifying the **b2** dimension (top flange width) of the I profile.
        t1
            A Float specifying the **t1** dimension (bottom flange thickness) of the I profile.
        t2
            A Float specifying the **t2** dimension (top flange thickness) of the I profile.
        t3
            A Float specifying the **t3** dimension (web thickness) of the I profile.

        Returns
        -------
        IProfile
            An IProfile object.

        Raises
        ------
        RangeError

        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the IProfile object.

        Raises
        ------
        RangeError

        """
        ...



from abqpy.decorators import abaqus_class_doc

from ..Adaptivity.AdaptivityStep import AdaptivityStep
from ..StepOutput.OutputStep import OutputStep
from ..TableCollection.TableCollectionStep import TableCollectionStep


@abaqus_class_doc
class Step(AdaptivityStep, OutputStep, TableCollectionStep):
    """The Step object stores the parameters that determine the context of the step. The Step
    object is the abstract base type for other Step objects. The Step object has no explicit
    constructor. The methods and members of the Step object are common to all objects
    derived from the Step.

    .. note::
        This object can be accessed by::

            import step
            mdb.models[name].steps[name]
    """

    ...
